This folder contains specifications for how to flag a dicom image for a possible burned in annotation. The specification file is called [deid.dicom](deid.dicom) and this README will contain a history of it's updates and changes.

## Deid.dicom Updates
 -'7/2/2017': created with [current CTP](https://github.com/johnperry/CTP/blob/8a3c595b60442e6d74aec4098eaed5dcf8ff8770/source/files/examples/example-dicom-pixel-anonymizer.script) criteria, which are also present on the Stanford run CTP.

